==> Gitlab-Issue-Listing-Script-0.3.tar: Gitlab-Issue-Listing-Script-0.3/html/templates/html/release.php <==
<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;
?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title><?php echo htmlspecialchars($release['project']->name_with_namespace); ?> / Release: <?php echo htmlspecialchars($release['release']->name); ?></title>
<!-- <link rel="alternate" type="application/json" href="<?php //echo qs2sef("proj={$project->pkey}",".json");?>"> -->

<meta name="description" content="<?php echo htmlentities(utf8_encode($release['release']->description)); ?>" />

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($release['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($release['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($release['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'><?php echo htmlspecialchars($release['project']->name_with_namespace);?>: <?php echo htmlspecialchars($release['project']->name) ?> / Release: <?php echo htmlspecialchars($release['release']->name); ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$release['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($release['project']->name_with_namespace);?></a></li>
        <li>Milestones</li>
        <li><a href="<?php echo GILSUtils::qs2sef("release={$release['release']->tag_name}&projpath={$release['project']->path_with_namespace}");?>"><?php echo $release['release']->name; ?></a></li>
</ul>
<hr />


<div class="projlinksblock">
    
</div>

<div>
    <div class="row">
        <div class="leftcol" id="issrptr">Git Tag: <?php echo htmlspecialchars($release['release']->tag_name); ?></div>
    
        <div class="rightcol" id="issassignee">Commit: 
            <a href="<?php echo GILSUtils::qs2sef("commit={$release['release']->commit->id}&commitproj={$release['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($release['release']->commit->short_id); ?></a>
        </div>
    </div>
    

</div>
<div style="clear: both"></div>


<div class='projdesc'>
    <?php
        echo GILSUtils::markdownToHTML($release['release']->description);
    ?>
</div>



<div >Snapshots 
<ul>
    <?php foreach($release['release']->assets->sources as $snp): 

    // Rework the snapshot url
    $s = explode("/", $snp->url); 
    array_shift($s);
    array_shift($s);
    array_shift($s);
    $sn_url =  implode("/", $s);
    $fname = array_pop($s);
    ?>
        <li><a href="<?php echo GILSUtils::qs2sef("snapshot=$sn_url"); ?>"><?php echo htmlspecialchars($fname); ?></a></li>

    <?php endforeach; ?>
</ul>

</div>

<hr />
<br />







<?php if (property_exists($release['release'],"milestones")): ?>

        <div class="mslist"><b>Milestones</b>: 
            <ul>
                <?php foreach($release['release']->milestones as $ms): ?>
                    <li><a href="<?php echo GILSUtils::qs2sef("milestone={$ms->id}&projpath={$release['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($ms->title); ?></a></li>
                <?php endforeach; ?>
                
            
            </ul>
        
        </div>

<?php endif; ?>


<div class="gitlablink">
    <a href="<?php echo GILSUtils::forceHTTPS($release['release']->_links->self);?>">View in Gitlab</a>
</div>

<hr />
<br />


<!--/sphider_noindex-->

</body>
</html>

==> Gitlab-Issue-Listing-Script-v0.5.tar: Gitlab-Issue-Listing-Script-v0.5/html/templates/html/release.php <==
<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;
?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Release: <?php echo htmlspecialchars($release['release']->name); ?> : <?php echo htmlspecialchars($release['project']->name_with_namespace); ?></title>
<!-- <link rel="alternate" type="application/json" href="<?php //echo qs2sef("proj={$project->pkey}",".json");?>"> -->

<meta name="description" content="<?php echo htmlentities(utf8_encode($release['release']->description)); ?>" />

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($release['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($release['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($release['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'><?php echo htmlspecialchars($release['project']->name_with_namespace);?> / Release: <?php echo htmlspecialchars($release['release']->name); ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$release['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($release['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$release['project']->path_with_namespace}");?>#releases">Releases</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("release={$release['release']->tag_name}&projpath={$release['project']->path_with_namespace}");?>"><?php echo $release['release']->name; ?></a></li>
</ul>
<hr />


<div class="projlinksblock">
    
</div>

<div>
    <div class="row">
        <div class="leftcol" id="issrptr">Git Tag: <?php echo htmlspecialchars($release['release']->tag_name); ?></div>
    
        <div class="rightcol" id="issassignee">Commit: 
            <a href="<?php echo GILSUtils::qs2sef("commit={$release['release']->commit->id}&commitproj={$release['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($release['release']->commit->short_id); ?></a>
        </div>
    </div>
    
    <div class="row">
        <div class="leftcol" id="reldate">Released: <?php echo date('d M Y H:i:s', strtotime($release['release']->released_at)); ?></div>
    
        <div class="rightcol">
        </div>
    </div>

</div>
<div style="clear: both"></div>


<div class='projdesc'>
    <?php
        echo GILSUtils::markdownToHTML($release['release']->description);
    ?>
</div>



<div >Snapshots 
<ul>
    <?php foreach($release['release']->assets->sources as $snp): 

    // Rework the snapshot url
    $s = explode("/", $snp->url); 
    array_shift($s);
    array_shift($s);
    array_shift($s);
    $sn_url =  implode("/", $s);
    $fname = array_pop($s);
    ?>
        <li><a href="<?php echo GILSUtils::qs2sef("snapshot=$sn_url"); ?>"><?php echo htmlspecialchars($fname); ?></a></li>

    <?php endforeach; ?>
</ul>

</div>

<hr />
<br />







<?php if (property_exists($release['release'],"milestones")): ?>

        <div class="mslist"><b>Milestones</b>: 
            <ul>
                <?php foreach($release['release']->milestones as $ms): ?>
                    <li><a href="<?php echo GILSUtils::qs2sef("milestone={$ms->id}&projpath={$release['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($ms->title); ?></a></li>
                <?php endforeach; ?>
                
            
            </ul>
        
        </div>

<?php endif; ?>

<?php if ($template_vars['display_gitlab_links']): ?>
    <div class="gitlablink">
        <a href="<?php echo GILSUtils::forceHTTPS($release['release']->_links->self);?>">View in Gitlab</a>
    </div>
<?php endif; ?>

<hr />
<br />


<!--/sphider_noindex-->

</body>
</html>
